#include <AccelStepper.h>
#include <Encoder.h>

// Motor
int step1 = 2;     // uln2003 in1
int step2 = 3;     // uln2003 in2
int step3 = 4;     // uln2003 in3
int step4 = 5;     // uln2003 in4
int HALFSTEP = 8;
int MaxSpeed = 200.0;
int Acceleration = 1000;
int Speed = 200;

// Definiranje gdje staje motor
int maxMotor = 2100;     // 2100 je za 180 stupnjeva
int minMotor = 0;

// Photoresistor
int photo1 = A4;       // Signal od fotootpornika 1
int photo1Val = 0;     // Spremnik valute fotootpornika 1
int photo2 = A5;       // Signal od fotootpornika 2
int photo2Val = 0;     // Spremnik valute fotootpornika 2

// Leds
int led1 = 8;      // Prva led dioda
int led2 = 9;      // Druga led dioda
int led3 = 10;     // Treća led dioda

// Encoder
int clkPin = 11;
int dtPin = 12;


AccelStepper stepper(HALFSTEP, step1, step3, step2, step4);
Encoder enc(clkPin, dtPin);

void setup() {
  
  // Konfiguriranje ulaza i izlaza
  pinMode(led1, OUTPUT);
  pinMode(led2, OUTPUT);
  pinMode(led3, OUTPUT);
  
  pinMode (clkPin, INPUT);
  pinMode (dtPin, INPUT);
  
  stepper.setMaxSpeed(MaxSpeed);
  stepper.setAcceleration(Acceleration);
  stepper.setSpeed(Speed);
}

void loop() {
  readPhotoresistor();
}

void readPhotoresistor() {
  photo1Val = (analogRead(photo1)/4);
  ledControl();
  if ( photo1Val < 255*0.30  )     // Zatvaraj roletu ako je sumrak
  {
    stepper.moveTo(maxMotor);
    stepper.run();
}
else if ( photo1Val >= 255*0.30  )     // Otvaraj roletu ako je svitanje
  {
    stepper.moveTo(minMotor);
    stepper.run();
}
}

void ledControl() {
  int change = getEncoderTurn ();     // Dohvati podatke od enkodera
  photo1Val = (analogRead(photo1)/4);
  photo2Val = (analogRead(photo2)/4)+(change*10);     // Ovaj *10, to je sensitiv od enkodera, znaci da svaki zub(okret) dodaje ili oduzima 10 na valuti
  if( 0 < photo2Val && photo2Val < 255*0.24 ) { led(1,1,1); }     // 0.24 je 24% za unutarnju fotodiodu znaci od 0 do 24% trebaju biti sve 3 upaljene
  else if( 255*0.25 < photo2Val && photo2Val < 255*0.30 ) { led(1,1,0); }     // od 25% do 30% upali dvije ledice
  else if( 255*0.31 < photo2Val && photo2Val < 255*0.36 ) { led(1,0,0); }     // od 31% do 36% upali 2 ledice
  else if( 255*0.37 < photo2Val && photo2Val < 255*0.41  ) { led(0,0,0);}     // od 37% do 41 % upali 3 ledice
  
}

void led(int x,int y, int z) {
  digitalWrite(led1, x);
  digitalWrite(led2, y);
  digitalWrite(led3, z);
}

int getEncoderTurn ()
{
   long oldPosition  = -999;
  long newPosition = enc.read();
  if (newPosition != oldPosition) {
    oldPosition = newPosition;
  }
  return newPosition;
}
